<?php

namespace App\Http\Controllers\Api\Auth;

use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Traits\ResponseTrait;
use App\Mail\EmailVerification;
use App\Interfaces\AuthInterface;
use Illuminate\Support\Facades\URL;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use App\Http\Requests\Auth\RegisterRequest;

class RegisterController extends Controller
{
    use ResponseTrait;

    protected $auth;

    public function __construct(AuthInterface $authInterface)
    {
        $this->auth = $authInterface;
    }
    //REGISTER API URL:http://127.0.0.1:8000/api/v1/register
    public function Register(RegisterRequest $request)
    {
        $data = [];
        $email = $request->email;
        $data['name'] = $request->input('name');
        $data['email'] = $request->input('email');
        $data['password'] = Hash::make($request->input('password'));
        $data['phone_number'] = $request->input('phone');
        $data['dob'] = $request->input('dob');
        $data['referral_code'] = uniqid(time() . Str::random(8));
        $data['question1'] = $request->input('question1');
        $data['question2'] = $request->input('question2');

        //generate referral link
        $referral_url = config('app.frontend_url') . '/' . 'register?ref=' . $data['referral_code'];
        $data['referral_link'] = $referral_url;

        try {
            //if user registered with valid referral code
            if (isset($request->referral_code)) {
                $code = $request->referral_code;
                //get referred user data
                $referred_user_data = $this->auth->referredUserData($code);
                //if referred user data is exist
                if (count($referred_user_data) > 0) {
                    //get user id who is used to referred user referral code
                    $user_id = $this->auth->getRegisterUserId($data);
                    //insert network data
                    $network_data = [];
                    $network_data['referral_code'] = $code;
                    $network_data['user_id'] = $user_id;
                    $network_data['parent_user_id'] = $referred_user_data[0]['id'];
                    $network_user = $this->auth->createNetworkUser($network_data);
                    //get user
                    $user = $this->auth->getUserById($user_id);
                    //create token
                    $token = $user->createToken('app')->plainTextToken;
                    //mail send using queue for email verification
                    Mail::to($email)->queue(new EmailVerification($user));
                    //mail send
                    // Mail::to($email)->send(new EmailVerification($user));
                    //send register response
                    return $this->authResponse($user, $token, 'User registered successfully.please check your email for account activation', null, 200);
                } else {
                    return $this->responseError('Error', 'Invalid Referral code', 401);
                }
            } else {
                $user = $this->auth->RegisterUser($data);
                //create token
                $token = $user->createToken('app')->plainTextToken;
                //mail send using queue for email verification
                // Mail::to($email)->queue(new EmailVerification($user));
                Mail::to($email)->send(new EmailVerification($user));
                //send register response
                return $this->authResponse($user, $token, 'User registered successfully.please check your email for account activation', null, 200);
            }
        } catch (\Exception $e) {
           return $this->authResponse(null,null,'User not registered', $e->getMessage(), 400);
        }
    }
}
