<?php

namespace App\Http\Controllers\Api\Auth;

use Illuminate\Http\Request;
use App\Traits\ResponseTrait;
use App\Interfaces\AuthInterface;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use App\Http\Requests\Auth\ResetPasswordRequest;

class ResetPasswordController extends Controller
{
    use ResponseTrait;

    protected $auth;

    public function __construct(AuthInterface $authInterface)
    {
        $this->auth = $authInterface;
    }

    public function ResetPassword(ResetPasswordRequest $request)
    {
        $email = $request->input('input_email');
        $password = Hash::make($request->input('password'));
        //check email
        $emailCheck = $this->auth->emailCheck($email);

        if (!$emailCheck) {
            return response()->json([
                'statusCode' => false,
                'message' => 'Email not found',
            ]);
        }
        try {
            //update password
            $this->auth->updatePassword($email, $password);
            //delete email
            $this->auth->deleteEmail($email);
            return response()->json([
                'statusCode' => true,
                'message' => 'Password reset successful',
            ]);
        } catch (\Exception $e) {
            return response()->json([
                'error' => $e->getMessage(),
            ]);
        }
    } //end of method
}
