<?php

namespace App\Http\Controllers\Api\Subscription;

use App\Models\Plan;
use Illuminate\Http\Request;
use App\Traits\ResponseTrait;
use App\Http\Controllers\Controller;
use App\Interfaces\SubscriptionInterface;
use App\Resolvers\PaymentPlatformResolver;

class StripeSubscriptionController extends Controller
{
    use ResponseTrait;

    protected $paymentPlatformResolver, $sub;

    public function __construct(
        PaymentPlatformResolver $paymentPlatformResolver,
        SubscriptionInterface $subscriptionInterface
        )
    {
        $this->paymentPlatformResolver = $paymentPlatformResolver;
        $this->sub=$subscriptionInterface;
    }

    public function showSubscription()
    {

    }//end of showSubscription

    public function processSubscription(Request $request)
    {
        $paymentPlatform=$this->paymentPlatformResolver->resolveService($request->payment_platform);

        session()->put('subscriptionPlatformId',$request->payment_platform);

        return $paymentPlatform->handleSubscription($request);
    }//end of processSubscription

    public function approvalSubscription(Request $request)
    {
        try{
            $plan=Plan::where('slug',$request->plan)->firstOrFail();
            $user=$request->user();
            $paymentPlatform=$this->paymentPlatformResolver->resolveService(2);
            $subscriptionDetails=$paymentPlatform->subscriptionDetails($request->subscriptionId);

            if($subscriptionDetails->status ==="active" && $request->plan!==null){
                if($this->sub->NotExistingSubscriberId($request->subscriptionId)){
                    $data=[];
                    $data['subscription_id']=$request->subscriptionId;
                    $data['active_until']=now()->addDays($plan->duration_in_days);
                    $data['payment_method']=$request->payment_method;
                    $data['email']=auth()->user()->email?auth()->user()->email:$request->email;
                    $data['user_id']=$user->id;
                    $data['plan_id']=$plan->id;
                    $data['payment_platform_id']=2;
                    try{
                        $subscription=$this->sub->CreateSubscription($data);
                        return $this->responseSuccess($subscription,'Subscription active successfully', 200);

                    }catch(\Exception $e){
                        return $this->responseError($e->getMessage(), 'Subscription activation failed', 400);
                    }

                }
            }

        }catch(\Exception $e){
            return $this->responseError($e->getMessage(), 'Subscription activation failed', 400);
        }

    }//end of processSubscription

    public function canceledSubscription()
    {

    }//end of canceledSubscription

    public function userSubscriptionDetails($email)
    {
        $paymentPlatform=$this->paymentPlatformResolver->resolveService(2);
        //get subscriber user using email address
        $subscribeUser=$this->sub->getSubscriber($email);
        try{
            $subscriptionDetails=$paymentPlatform->subscriptionDetails($subscribeUser->subscription_id);
            if($subscriptionDetails->status==="active" ){
                return $this->responseSuccess($subscriptionDetails,'Subscription active successfully', 200);
            }
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(), 'Subscription activation failed', 400);
        }
    }//end of subscriptionDetails



}
